@@ -98,4 +98,10 @@ class TopTitleBarWidget(QWidget):
         return self.__titleLbl
 
     def getBtnWidget(self):
-        return self.__btnWidget
\ No newline at end of file
+        return self.__btnWidget
+
+    # to maintain the maximum size intact
+    def event(self, e):
+        if int(e.type()) == 76:
+            self.setMaximumHeight(self.sizeHint().height())
+        return super().event(e)
\ No newline at end of file
